# phanns_dataset_builder

To use:

```
git clone https://github.com/seanfahey1/phanns_dataset_builder.git
```

```
cd phanns_dataset_builder
pip install -r requirements
```

Edit the positive_terms.toml file.

```
python NCBI_fetch.py -c path/to/config.toml -e [your email here] -a [your api key here]
```
